==> qtjambi-charts-debuginfo-macos-5.15.20.jar: sources/QtJambiCharts/QPieModelMapper_shell.h <==
#ifndef QPIEMODELMAPPER_SHELL_H
#define QPIEMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qpiemodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qpieseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QPieModelMapper_shell : public QtCharts::QPieModelMapper, public QtJambiShellInterface
{
public:
    QPieModelMapper_shell(QObject* parent0 = nullptr);
    ~QPieModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPieModelMapper_access : public QtCharts::QPieModelMapper
{
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_labelsSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setLabelsSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint labelsSection0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QtCharts_QPieSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
    void __qt_setValuesSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint valuesSection0);
    jint __qt_valuesSection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPIEMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-macos-6.5.3.jar: sources/QtJambiCharts/QPieModelMapper_shell.h <==
#ifndef QPIEMODELMAPPER_SHELL_H
#define QPIEMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qpiemodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qpieseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QPieModelMapper_shell : public QPieModelMapper, public QtJambiShellInterface
{
public:
    QPieModelMapper_shell(QObject* parent0 = nullptr);
    ~QPieModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPieModelMapper_access : public QPieModelMapper
{
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_first(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_labelsSection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_model(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint count0);
    void __qt_setFirst_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint first0);
    void __qt_setLabelsSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint labelsSection0);
    void __qt_setModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID model0);
    void __qt_setOrientation_Qt_Orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint orientation0);
    void __qt_setSeries_QPieSeries_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID series0);
    void __qt_setValuesSection_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint valuesSection0);
    jint __qt_valuesSection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPIEMODELMAPPER_SHELL_H
